Learn R Programming

mmpp (version 0.1)

iipmetric: Compute Intensity Inner Product Metrics

Description

For the analysis of point process, intensity function plays a central roll. Paiva et al. (2009) proposed to use the intensity function for defining the inner product between SPP instances.

Usage

iipmetric(S1, S2, measure = "sim", tau = 1, M = NULL,
  abs.tol = .Machine$double.eps^0.25)

Arguments

S1
marked point process data
S2
marked point process data
measure
"sim" for similarity and "dist" for distance. Default "sim".
tau
parameter for filtering function.
M
a precision matrix for filter of marks, i.e., exp( - r' M r) is used for filtering marks. It should be symmetric and positive semi-definite.
abs.tol
absolute tolerance for numerical integration.

Value

  • similarity or distance between two inputs (marked) point process S1 and S2.

Details

iipmetric computes intensity inner product metric. Intensity function for the point process instance is estimated by kernel density estimator. This function adopts Gaussian kernels for the sake of computational efficiency.

References

A. R. C. Paiva, Il Park, and Jose; C. Principe. 2009. A reproducing kernel Hilbert space framework for spike train signal processing. Neural Comput. 21, issue 2, pp. 424-449.

Examples

Run this code
##The aftershock data of 26th July 2003 earthquake of M6.2 at the northern Miyagi-Ken Japan.
data(Miyagi20030626)
##  no. longitude latitude magnitude     time  depth year month day
## split events by 7-day
sMiyagi <- splitMPP(Miyagi20030626,h=60*60*7,scaleMarks=TRUE)$S
N <- 10
tau <- 0.1
sMat <- matrix(0,N,N)
  cat("calculating intensity inner product...")
 for(i in 1:(N)){
   cat(i,"")
   for(j in i:N){
     S1 <- sMiyagi[[i]]$time;S2 <- sMiyagi[[j]]$time
    sMat[i,j] <- iipmetric(S1,S2,tau=tau,M=diag(1,4))
   }
 }
 sMat <- sMat+t(sMat)
 tmpd <- diag(sMat) <- diag(sMat)/2
 sMat <- sMat/sqrt(outer(tmpd,tmpd))
image(sMat)

Run the code above in your browser using DataLab